@@ -114,7 +114,7 @@ module.exports = generators.Base.extend({
       // create module.js
       var moduleFile = this.readFileAsString(path.join(__dirname, '../templates/scripts/module.js'))
       moduleFile = moduleFile.replace(new RegExp("{{APP_NAME}}", 'g'), this.appName);
-      var moduleFilePath = this.jsPath + 'modules.js'
+      var moduleFilePath = this.jsPath + '/modules.js'
       this.write(moduleFilePath, moduleFile);
       this.scriptsFile.push(moduleFilePath);
     },
@@ -138,8 +138,6 @@ module.exports = generators.Base.extend({
         } else {
           console.log(chalk.yellow('Created a new Cordova project with name "' + this.appName + '" and id "' + this.appId + '"'));
           mkdir.sync('local_plugins');
-        
-          
         }
         done();
       }.bind(this));
