@@ -5,7 +5,8 @@ angular.module('{{APP_NAME}}.services').factory('TwitterAuthService', [
   '$ionicPlatform',
   '$cordovaOauthUtility',
   'TwitterPluginService',
-  function ($q, $cordovaSocialSharings, $ionicPlatform, TwitterPluginService) {
+  'KEYS',
+  function ($q, $cordovaSocialSharings, $ionicPlatform, TwitterPluginService, KEYS) {
     var login = function () {
       var q = $q.defer();
       TwitterPluginService.login()
