@@ -6,13 +6,13 @@ var flurryIdPrompt = [
   {
     type: 'input',
     name: 'FLURRY_ID_DEV',
-    message: 'Enter your Flurry_id for your development environment. (You can let it blank and fill it later in Gruntfile.js)',
+    message: 'Enter your Flurry_id for your development environment.\n (You can let it blank and fill it later in Gruntfile.js)',
     default: 'FLURRY_ID_DEV'
   },
   {
     type: 'input',
     name: 'FLURRY_ID_PROD',
-    message: 'Enter your Flurry_id for your production environment. (You can let it blank and fill it later in Gruntfile.js)',
+    message: 'Enter your Flurry_id for your production environment.\n (You can let it blank and fill it later in Gruntfile.js)',
     default: 'FLURRY_ID_PROD'
   }
 ];
@@ -20,25 +20,25 @@ var parseIdPrompt = [
   {
     type: 'input',
     name: 'PARSE_APP_DEV_ID',
-    message: 'Enter your PARSE_APP_ID for your development environment. (You can let it blank and fill it later in Gruntfile.js)',
+    message: 'Enter your PARSE_APP_ID for your development environment.\n (You can let it blank and fill it later in Gruntfile.js)',
     default: 'PARSE_APP_DEV_ID'
   },
   {
     type: 'input',
     name: 'PARSE_CLIENT_DEV_ID',
-    message: 'Enter your PARSE_CLIENT_ID for your development environment. (You can let it blank and fill it later in Gruntfile.js)',
+    message: 'Enter your PARSE_CLIENT_ID for your development environment.\n (You can let it blank and fill it later in Gruntfile.js)',
     default: 'PARSE_CLIENT_DEV_ID'
   },
   {
     type: 'input',
     name: 'PARSE_APP_PROD_ID',
-    message: 'Enter your PARSE_APP_ID for your production environment. (You can let it blank and fill it later in Gruntfile.js)',
+    message: 'Enter your PARSE_APP_ID for your production environment.\n (You can let it blank and fill it later in Gruntfile.js)',
     default: 'PARSE_APP_DEV_ID'
   },
   {
     type: 'input',
     name: 'PARSE_CLIENT_PROD_ID',
-    message: 'Enter your PARSE_CLIENT_ID for your production environment. (You can let it blank and fill it later in Gruntfile.js)',
+    message: 'Enter your PARSE_CLIENT_ID for your production environment.\n (You can let it blank and fill it later in Gruntfile.js)',
     default: 'PARSE_CLIENT_PROD_ID'
   }
 ];
@@ -46,25 +46,25 @@ var facebookPrompt = [
   {
     type: 'input',
     name: 'FACEBOOK_APP_NAME_DEV',
-    message: 'Enter your Facebook APP_NAME for your development environment. (You can let it blank and fill it later in Gruntfile.js)',
+    message: 'Enter your Facebook APP_NAME for your development environment.\n (You can let it blank and fill it later in Gruntfile.js)',
     default: 'FACEBOOK_APP_NAME_DEV'
   },
   {
     type: 'input',
     name: 'FACEBOOK_APP_ID_DEV',
-    message: 'Enter your Facebook APP_ID for your development environment. (You can let it blank and fill it later in Gruntfile.js)',
+    message: 'Enter your Facebook APP_ID for your development environment.\n (You can let it blank and fill it later in Gruntfile.js)',
     default: 'FACEBOOK_APP_ID_DEV'
   },
   {
     type: 'input',
     name: 'FACEBOOK_APP_NAME_PROD',
-    message: 'Enter your Facebook APP_NAME for your production environment. (You can let it blank and fill it later in Gruntfile.js)',
+    message: 'Enter your Facebook APP_NAME for your production environment.\n (You can let it blank and fill it later in Gruntfile.js)',
     default: 'FACEBOOK_APP_NAME_PROD'
   },
   {
     type: 'input',
     name: 'FACEBOOK_APP_ID_PROD',
-    message: 'Enter your Facebook APP_ID for your production environment. (You can let it blank and fill it later in Gruntfile.js)',
+    message: 'Enter your Facebook APP_ID for your production environment.\n (You can let it blank and fill it later in Gruntfile.js)',
     default: 'FACEBOOK_APP_ID_PROD'
   },
 ];
