@@ -84,7 +84,6 @@ module.exports = {
         self.routes = [];
         showRouteStatePrompt(self, done);
       } else {
-
         done();
       }
     }.bind(self));
@@ -92,7 +91,6 @@ module.exports = {
   install: function(self) {
     var routes = self.routes;
     if (routes) {
-      var done = self.async();
       var configRoutes = '';
       if (routes.length > 0) {
         configRoutes = '$stateProvider\n\t';
@@ -107,7 +105,6 @@ module.exports = {
       var filePath = path.join(self.jsPath, 'config.js');
       self.write(filePath, file);
       self.scriptsFile.push(filePath);
-      done();      
     }
   }
 };
